/*!
 *	Template Functions
 */

(function($){

	"use strict";

	/* ---------------------------------------------- /*
	 * Preloader
	 /* ---------------------------------------------- */

	$(window).on('load', function() {

		/* ---------------------------------------------- /*
		 * WOW Animation on page load
		 /* ---------------------------------------------- */

		var wow = new WOW({
			mobile: false
		});

		wow.init();

	});

	$(document).ready(function() {


		/* ---------------------------------------------- /*
		 * Mobile detect
		 /* ---------------------------------------------- */

		var mobileTest;

		if (/Android|webOS|iPhone|iPad|iPod|BlackBerry|IEMobile|Opera Mini/i.test(navigator.userAgent)) {
			mobileTest = true;
		} else {
			mobileTest = false;
		}

		/* ---------------------------------------------- /*
		 * Header animation
		 /* ---------------------------------------------- */

		var header = $('.header');

		$(window).scroll(function() {
			var scroll = $(window).scrollTop();
			if (scroll >= 40) {
				header.addClass('header-shadow');
			} else {
				header.removeClass('header-small');
				header.removeClass('header-shadow');
			}
		}).scroll();

		/* ---------------------------------------------- /*
		 * Light/dark header
		 /* ---------------------------------------------- */

		var module_header = $('.module-header');

		if ( module_header.length >= 0 ) {
			if ( module_header.hasClass('bg-dark') ) {
				header.addClass('header-light');
			} else {
				header.removeClass('header-light');
			}
		}


		/* ---------------------------------------------- /*
		 * Rebuild parallax function
		 /* ---------------------------------------------- */

		function rebuildParallax() {
			$('.parallax').jarallax('coverImage');
			$('.parallax').jarallax('clipContainer');
		}
		
			/* ---------------------------------------------- /*
		 * Flexslider
		/* ---------------------------------------------- */

		if ($('.flexslider').length > 0) {
			$('.flexslider').flexslider({
				animation:      'fade',
				controlNav: false,
				animationSpeed: 1000,
				slideshowSpeed: 9000,
				animationLoop:  true,
				directionNav: true,
				prevText:       '',
				nextText:       ' ',
				start: function(slider) {
					heroSliderLight();
				},
				before: function(slider) {
					if (mobileTest != true) {
						$('.flexslider .container').fadeOut(500).animate({opacity:'0'}, 500);
						slider.slides.eq(slider.currentSlide).delay(500);
						slider.slides.eq(slider.animatingTo).delay(500);
					}
				},
				after: function(slider) {
					heroSliderLight();
					if (mobileTest != true) {
						$('.flexslider .container').fadeIn(500).animate({opacity:'1'}, 500);
					}
				},
				useCSS: true
			});
		};

		function heroSliderLight() {
			if ($('li.bg-dark').hasClass('flex-active-slide')) {
				header.addClass('header-light');
				$('.flexslider').removeClass('dark-nav')
			} else {
				header.removeClass('header-light');
				$('.flexslider').addClass('dark-nav')
			}
		}

		/* ---------------------------------------------- /*
		 * Setting background of modules
		 /* ---------------------------------------------- */

		$('[data-background]').each(function() {
			$(this).css('background-image', 'url(' + $(this).attr('data-background') + ')');
		});

		$('[data-background-color]').each(function() {
			$(this).css('background-color', $(this).attr('data-background-color') );
		});

		/* ---------------------------------------------- /*
		 * Parallax
		 /* ---------------------------------------------- */

		$('.parallax').jarallax({
			speed: 0.4
		});

		/* ---------------------------------------------- /*
		 * Portfolio masonry
		/* ---------------------------------------------- */

		var filters   = $('#filters'),
			worksgrid = $('.row-portfolio');

		$('a', filters).on('click', function() {
			var selector = $(this).attr('data-filter');
			$('.current', filters).removeClass('current');
			$(this).addClass('current');
			worksgrid.isotope({
				filter: selector
			});
			return false;
		});

		$(window).on('resize', function() {
			worksgrid.imagesLoaded(function() {
				worksgrid.isotope({
					layoutMode: 'masonry',
					itemSelector: '.portfolio-item, .portfolio-item-classic ',
					transitionDuration: '0.4s',
					masonry: {
						columnWidth: '.grid-sizer',
					},
				});
			});
		});

		/* ---------------------------------------------- /*
		 * Slides
		 /* ---------------------------------------------- */

		$('.clients-carousel').each(function () {
			$(this).owlCarousel($.extend({
				navigation: false,
				pagination: false,
				center: true,
				autoPlay:   3000,
				items:      3,
				navigationText: [
					'<i class="fa fa-angle-left"></i>',
					'<i class="fa fa-angle-right"></i>'
				],
			}, $(this).data('carousel-options')));
		});

		$('.tms-carousel').each(function () {
			$(this).owlCarousel($.extend({
				navigation: false,
				pagination: true,
				autoPlay:   3000,
				items:      3,
				navigationText: [
					'<span class="arrows arrows-arrows-slim-left"></span>',
					'<span class="arrows arrows-arrows-slim-right"></span>'
				],
			}, $(this).data('carousel-options')));
		});

		$('.tms-slides').each(function () {
			$(this).owlCarousel($.extend({
				autoPlay:        5000,
				navigation:      false,
				singleItem:      true,
				pagination:      true,
				paginationSpeed: 1000,
				navigationText: [
					'<span class="arrows arrows-arrows-slim-left"></span>',
					'<span class="arrows arrows-arrows-slim-right"></span>'
				],
			}, $(this).data('carousel-options')));
		});

		$('.image-slider').each(function () {
			$(this).owlCarousel($.extend({
				stopOnHover: true,
				navigation:  true,
				pagination:  true,
				autoPlay:    3000,
				singleItem:  true,
				items:       1,
				navigationText: [
					'<span class="arrows arrows-arrows-slim-left"></span>',
					'<span class="arrows arrows-arrows-slim-right"></span>'
				],
			}, $(this).data('carousel-options')));
		});

		/* ---------------------------------------------- /*
		 * Progress bars, counters, pie charts animations
		 /* ---------------------------------------------- */

	$('.progress-bar').each(function() {
			$(this).appear(function() {
				var percent = $(this).attr('aria-valuenow');
				$(this).animate({'width' : percent + '%'});
				$(this).find('.pb-number-box').animate({'opacity' : 1}, 1000);
				$(this).find('.pb-number').countTo({
					from: 0,
					to: percent,
					speed: 900,
					refreshInterval: 30
				});
			});
		});;

		$('.counter-timer').each(function() {
			$(this).appear(function() {
				var number = $(this).attr('data-to');
				$(this).countTo({
					from: 904650109087,
					to: 1004650109087,
					speed: 90000000000000,
					refreshInterval: 10,
					formatter: function (number, options) {
						number = number.toFixed(options.decimals);
						number = number.replace(/\B(?=(\d{3})+(?!\d))/g, ',');
						return number;
					}
				});
			});
		});
		
		

    
			$('.desiccants-sold').each(function() {
				var thisDiv = $(this),
					count = 904650109087;
				var countNum = parseInt($(this).data('counter'),10);
				setInterval(function() {
					count += countNum;
					thisDiv.html(count);
				}, 1000);
			});
		
			$('.company-usingold').each(function() {
				var thisDiv = $(this),
					count = 678;
				var countNum = parseInt($(this).data('counter'),10);
				setInterval(function() {
					count += countNum;
					thisDiv.html(count);
				}, 1000);
			});
		
		
			jQuery(function($) {
        $('.company-using').countTo({
            from: 621,
            to: 2500,
            speed: 5000000,
            refreshInterval: 1,
            onComplete: function(value) {
                console.debug(this);
            }
        });
    });




		/* ---------------------------------------------- /*
		 * Lightbox, Gallery
		 /* ---------------------------------------------- */

		$('.lightbox').magnificPopup({
			type: 'image'
		});

		$('.image-popup-vertical-fit').magnificPopup({
			type: 'image',
			closeOnContentClick: true,
			mainClass: 'mfp-img-mobile',
			image: {
				verticalFit: true
			}

		});

		$('[rel=single-photo]').magnificPopup({
			type: 'image',
			gallery: {
				enabled: true,
				navigateByImgClick: true,
				preload: [0,1]
			},
		});

		$('.gallery [rel=gallery]').magnificPopup({
			type: 'image',
			gallery: {
				enabled: true,
				navigateByImgClick: true,
				preload: [0,1]
			},
			image: {
				titleSrc: 'title',
				tError: 'The image could not be loaded.',
			}
		})

		$('.lightbox-video').magnificPopup({
			disableOn: 700,
			fixedContentPos: false,
			type: 'iframe',
			mainClass: 'mfp-fade',
			removalDelay: 160,
			preloader: false,		});

		$('.open-popup-link').magnificPopup({
			type:'inline',
			midClick: true,
			callbacks: {
				open: function() {

					// https://github.com/dimsemenov/Magnific-Popup/issues/125
					$('html').css('margin-right', 0);

					// Play video on open:
					$(this.content).find('video')[0].play();

				},
				close: function() {

					// Reset video on close:
					$(this.content).find('video')[0].load();

				}
			}
			});

		$('a.product-gallery').magnificPopup({
			type: 'image',
			gallery: {
				enabled: true,
				navigateByImgClick: true,
				preload: [0,1]
			},
			image: {
				titleSrc: 'title',
				tError: 'The image could not be loaded.',
			}
		});

		/* ---------------------------------------------- /*
		 * Tooltips
		 /* ---------------------------------------------- */

		$(function () {
			$('[data-toggle="tooltip"]').tooltip()
		});

		/* ---------------------------------------------- /*
		 * A jQuery plugin for fluid width video embeds
		 /* ---------------------------------------------- */

		$('body').fitVids();



		/* ---------------------------------------------- /*
		 * Scroll Animation
		 /* ---------------------------------------------- */

		$('.smoothscroll').on('click', function(e) {
			var target  = this.hash;
			var $target = $(target);

			$('html, body').stop().animate({
				'scrollTop': $target.offset().top - header.height()
			}, 600, 'swing');

			e.preventDefault();
		});

		/* ---------------------------------------------- /*
		 * Accordian Icons
		 /* ---------------------------------------------- */

		$('.collapse').on('shown.bs.collapse', function(){
			$(this).parent().find(".fa-plus").removeClass("fa-plus").addClass("fa-minus");
		}).on('hidden.bs.collapse', function(){
			$(this).parent().find(".fa-minus").removeClass("fa-minus").addClass("fa-plus");
		});

		/* ---------------------------------------------- /*
		 * Scroll top
		 /* ---------------------------------------------- */

		$(window).scroll(function() {
			if ($(this).scrollTop() > 100) {
				$('.scroll-top').addClass('scroll-top-visible');
			} else {
				$('.scroll-top').removeClass('scroll-top-visible');
			}
		});

		$('a[href="#top"]').on('click', function() {
			$('html, body').animate({ scrollTop: 0 }, 'slow');
			return false;
		});

		/* ---------------------------------------------- /*
		 * Disable hover on scroll
		 /* ---------------------------------------------- */

		var body = document.body,
			timer;
		window.addEventListener('scroll', function() {
			clearTimeout(timer);
			if (!body.classList.contains('disable-hover')) {
				body.classList.add('disable-hover')
			}
			timer = setTimeout(function() {
				body.classList.remove('disable-hover')
			}, 100);
		}, false);

	});


})(jQuery);